/*  ============================================================================
 *  Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  soc.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc
 *    - 64 soc file
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *  14-Mar-2005 brn Moved the Event Ids from csl_intc.h to soc64plus.h
 *  03-Oct-2005 dqb Merged socEdma3.h with soc64plus.h
 *  23-Jan-2006 rre Added System Event IDs and Interrupt Event IDs
 *  25-May-2006 NG  Added SMC and SMCP base address(s), instance(s) number and
 *                  instance count.
 *  03-Jul-2006 NG  Added DTF, ETB, PDMA, PSC, UTOPIA2 & TSIP base address(s),
 *                  instance(s) number and instance count.
 * =============================================================================
 */
#ifndef _SOC_H_
#define _SOC_H_

#include <cslr.h>
/**************************************************************************\
*
\**************************************************************************/

/*****************************************************************************\
* Static inline definition
\*****************************************************************************/
#ifndef CSL_IDEF_INLINE
#define CSL_IDEF_INLINE static inline
#endif

/**************************************************************************\
* Peripheral Instance count
\**************************************************************************/

/** @brief Number of BWMNGMT instances */
#define CSL_BWMNGMT_CNT                 1

/** @brief Number of DDR2 instances */
#define CSL_DDR2_CNT                    1

/** @brief Number of DTF instances */
#define CSL_DTF_CNT                     6

/** @brief Number of ECTL instances */
#define CSL_ECTL_CNT                    2

/** @brief Number of EDC instances */
#define CSL_EDC_CNT                     1

/** @brief Number of EDMA3 CC instances */
#define CSL_EDMA3_CC_CNT                1

/** @brief Number of EDMA3 TC instances */
#define CSL_EDMA3_TC_CNT                4

/** @brief Number of EMAC instances */
#define CSL_EMAC_CNT                    2

/** @brief Number of ETB instances */
#define CSL_ETB_CNT                     6

/** @brief Number of GPIO instances */
#define CSL_GPIO_CNT                    1

/** @brief Number of HPI instances */
#define CSL_HPI_CNT                    	1

/** @brief Number of I2C instances */
#define CSL_I2C_CNT                     1

/** @brief Number of MDIO instances */
#define CSL_MDIO_CNT                    1

/** @brief Number of PDMA instances */
#define CSL_PDMA_CNT                    1

/** @brief Number of PLLC instances */
#define CSL_PLLC_CNT                    3

/** @brief Number of PSC instances */
#define CSL_PSC_CNT                     1

/** @brief Number of SMC instances */
#define CSL_SMC_CNT                     1

/** @brief Number of SMCP instances */
#define CSL_SMCP_CNT                    6

/** @brief Number of SRIO instances */
#define CSL_SRIO_CNT                    1

/** @brief Number of TIMER 64 instances */
#define CSL_TMR_CNT                     12

/** @brief Number of TSIP instances */
#define CSL_TSIP_CNT                    3

/** @brief Number of UTOPIA2 instances */
#define CSL_UTOPIA2_CNT                 1


/**************************************************************************\
* Peripheral Instance definitions.
\**************************************************************************/

/** @brief Instance number of Bandwidth Management */
#define CSL_BWMNGMT                     (0)

/** @brief Peripheral Instance for DDR2 */
#define CSL_DDR2                        (0)

/** @brief Peripheral Instances for DTF */
#define CSL_DTF_0 			            (0)
#define CSL_DTF_1 			            (1)
#define CSL_DTF_2 			            (2)
#define CSL_DTF_3 			            (3)
#define CSL_DTF_4 			            (4)
#define CSL_DTF_5 			            (5)

/** @brief Peripheral Instance for ECTL 0 */
#define CSL_ECTL_0                     	(0)

/** @brief Peripheral Instance for ECTL 1 */
#define CSL_ECTL_1                     	(1)

/** @brief Peripheral Instance for EDC */
#define CSL_EDC_0 			            (0)

/** @brief Peripheral Instance of EDMA instances */
#define CSL_EDMA3                       (0)

/** @brief Peripheral Instance for EMAC 0 */
#define CSL_EMAC_0                     	(0)

/** @brief Peripheral Instance for EMAC 1 */
#define CSL_EMAC_1                     	(1)

/** @brief Peripheral Instance for ETB */
#define CSL_ETB_0 			            (0)
#define CSL_ETB_1 			            (1)
#define CSL_ETB_2 			            (2)
#define CSL_ETB_3 			            (3)
#define CSL_ETB_4 			            (4)
#define CSL_ETB_5 			            (5)

/** @brief Peripheral Instance for GPIO */
#define CSL_GPIO						(0)

/** @brief Peripheral Instance for HPI */
#define CSL_HPI                        	(0)

/** @brief Peripheral Instance for I2C */
#define CSL_I2C                         (0)

/** @brief Peripheral Instance for MDIO */
#define CSL_MDIO                       	(0)

/** @brief Instance number of L2 memory protection */
#define CSL_MEMPROT_L2                  (0)

/** @brief Instance number of L1P memory protection */
#define CSL_MEMPROT_L1P                 (1)

/** @brief Instance number of L1D memory protection */
#define CSL_MEMPROT_L1D                 (2)

/** @brief Instance number of memory protection config */
#define CSL_MEMPROT_CONFIG              (3)

/** @brief Peripheral Instance for PDMA */
#define CSL_PDMA                     	(0)

/** @brief Peripheral Instances for PLLC  */
#define CSL_PLLC_0                     	(0)
#define CSL_PLLC_1                     	(1)
#define CSL_PLLC_2                     	(2)

/** @brief Peripheral Instance for PSC */
#define CSL_PSC                         (0)

/** @brief Peripheral Instances for PWRDWN */
#define CSL_PWRDWN                      (0)

/** @brief Instance for SMC 1 */
#define CSL_SMC_0                     	(0)

/** @brief Instances for SMCP 1 */
#define CSL_SMCP_0                     	(0)
#define CSL_SMCP_1                     	(1)
#define CSL_SMCP_2                     	(2)
#define CSL_SMCP_3                     	(3)
#define CSL_SMCP_4                     	(4)
#define CSL_SMCP_5                     	(5)

/** @brief Peripheral Instance for SRIO */
#define CSL_SRIO                       	(0)

/** @brief Peripheral Instance of Timer64 instances */
#define CSL_TMR_0                       (0)
#define CSL_TMR_1                       (1)
#define CSL_TMR_2                       (2)
#define CSL_TMR_3                       (3)
#define CSL_TMR_4                       (4)
#define CSL_TMR_5                       (5)
#define CSL_TMR_6                       (6)
#define CSL_TMR_7                       (7)
#define CSL_TMR_8                       (8)
#define CSL_TMR_9                       (9)
#define CSL_TMR_10                      (10)
#define CSL_TMR_11                      (11)

/** @brief Peripheral Instance for TSIP */
#define CSL_TSIP_0 			            (0)
#define CSL_TSIP_1 			            (1)
#define CSL_TSIP_2 			            (2)

/** @brief Peripheral Instance for UTOPIA2 */
#define CSL_UTOPIA2                    	(0)

/**************************************************************************\
* Peripheral Base Address
\**************************************************************************/
/** @brief Bandwidth Management module address */
#define CSL_BWMNGMT_0_REGS	                (0x01820200u)

/** @brief Cache Module memory mapped address  */
#define CSL_CACHE_0_REGS                (0x01840000u)
/** #brief DDR2 Module memory mapped address  */
#define CSL_DDR2_0_REGS                 (0x78000000u)

/** @brief device configuration registers memory mapped address    */
#define CSL_DEV_REGS                        (0x02A80000u)

/** @brief Base address of DTF memory mapped registers */
#define CSL_DTF_0_REGS		                (0x02A80100u)
#define CSL_DTF_1_REGS		                (0x02A80110u)
#define CSL_DTF_2_REGS		                (0x02A80120u)
#define CSL_DTF_3_REGS		                (0x02A80130u)
#define CSL_DTF_4_REGS		                (0x02A80140u)
#define CSL_DTF_5_REGS		                (0x02A80150u)

/** @brief ECTL 0 Module memory mapped address  */
#define CSL_ECTL_0_REGS                    	(0x02C81000u)

/** @brief ECTL 1 Module memory mapped address  */
#define CSL_ECTL_1_REGS                    	(0x02CC1000u)

/** @brief EMAC 0 Module memory mapped address  */
#define CSL_EMAC_0_REGS                    	(0x02C80000u)

/** @brief EMAC 1 Module memory mapped address  */
#define CSL_EMAC_1_REGS                    	(0x02CC0000u)

/** @brief Base address of EDC memory mapped registers */
#define CSL_EDC_0_REGS                      (0x01846000u)

/** @brief Base address of Channel controller  memory mapped registers */
#define CSL_EDMA3CC_0_REGS              (0x02A00000u)

/** @brief Base address of Transfer controller  memory mapped registers */
#define CSL_EDMA3TC_0_REGS              (0x02A20000u)
#define CSL_EDMA3TC_1_REGS              (0x02A28000u)
#define CSL_EDMA3TC_2_REGS              (0x02A30000u)
#define CSL_EDMA3TC_3_REGS              (0x02A38000u)

/** #brief EMIF64 Module memory mapped address  */
#define CSL_EMIFB_0_REGS                (0x78000000)

/** @brief Base address of ETB memory mapped registers */
#define CSL_ETB_0_REGS		                (0x02C40000u)
#define CSL_ETB_1_REGS		                (0x02C41000u)
#define CSL_ETB_2_REGS		                (0x02C42000u)
#define CSL_ETB_3_REGS		                (0x02C43000u)
#define CSL_ETB_4_REGS		                (0x02C44000u)
#define CSL_ETB_5_REGS		                (0x02C45000u)

/** @brief GPIO Module memory mapped address  */
#define CSL_GPIO_0_REGS                 (0x02B00000u)

/** @brief HPI Module memory mapped address  */
#define CSL_HPI_0_REGS                 		(0x02880000u)

/** @brief I2C Module memory mapped address  */
#define CSL_I2C_0_REGS                  (0x02B04000u)

/** @brief IDMA Module memory mapped address  */
#define CSL_IDMA_0_REGS                 (0x01820000u)

/** @brief Base address of INTC memory mapped registers */
#define CSL_INTC_0_REGS 				(0x01800000u)

/** @brief Base address of UMC Memory protection registers */
#define CSL_MEMPROT_L2_REGS                 (0x0184A000u)

/** @brief Base address of PMC memory Protection registers */
#define CSL_MEMPROT_L1P_REGS                (0x0184A400u)

/** @brief Base address of DMC memory protection registers */
#define CSL_MEMPROT_L1D_REGS                (0x0184AC00u)

/** @brief Base address of CONFIG memory protection registers */
#define CSL_MEMPROT_CONFIG_REGS             (0x01820300u)

/** @brief MDIO Module memory mapped address  */
#define CSL_MDIO_0_REGS                    	(0x02C81800u)

/** @brief PDMA Module memory mapped address  */
#define CSL_PDMA_0_REGS                   	(0x02BC0000u)

/** @brief Base address of PDC registers */
#define CSL_PWRDWN_PDC_REGS 	            (0x01810000u)

/** @brief Base address of L2 power Down registers */
#define CSL_PWRDWN_L2_REGS	                (0x0184C000u)

/** @brief PLLC Module memory mapped addresses  */
#define CSL_PLLC_0_REGS                    	(0x029A0000u)
#define CSL_PLLC_1_REGS                    	(0x029C0000u)
#define CSL_PLLC_2_REGS                    	(0x029C0400u)

/** @brief PSC Module memory mapped address  */
#define CSL_PSC_REGS                    (0x02AE0000u)

/** @brief SMC 1 Module memory mapped address  */
#define CSL_SEC_CTL_0_REGS                 	(0x02AB8000u)

/** @brief SMC 1 Module memory mapped address  */
#define CSL_SMC_0_REGS                    	(0x02AA8000u)

/** @brief Base address of SMCP memory mapped registers */
#define CSL_SMCP_0_REGS                    	(0x02C20000u)
#define CSL_SMCP_1_REGS                    	(0x02C24000u)
#define CSL_SMCP_2_REGS                    	(0x02C28000u)
#define CSL_SMCP_3_REGS                    	(0x02C2C000u)
#define CSL_SMCP_4_REGS                    	(0x02C30000u)
#define CSL_SMCP_5_REGS                    	(0x02C34000u)

/** @brief SRIO Module memory mapped address  */
#define CSL_SRIO_0_REGS                    	(0x02D00000u)

/** @brief Base address of timer64 memory mapped registers */
#define CSL_TMR_0_REGS                      (0x025E0000u)
#define CSL_TMR_1_REGS                      (0x025F0000u)
#define CSL_TMR_2_REGS                      (0x02600000u)
#define CSL_TMR_3_REGS                      (0x02610000u)
#define CSL_TMR_4_REGS                      (0x02620000u)
#define CSL_TMR_5_REGS                      (0x02630000u)

#define CSL_TMR_6_REGS                      (0x02640000u)
#define CSL_TMR_7_REGS                      (0x02650000u)
#define CSL_TMR_8_REGS                      (0x02660000u)
#define CSL_TMR_9_REGS                      (0x02670000u)
#define CSL_TMR_10_REGS                     (0x02680000u)
#define CSL_TMR_11_REGS                     (0x02690000u)

/** @brief Base address of TSIP memory mapped registers */
#define CSL_TSIP_0_REGS                     (0x02500000u)
#define CSL_TSIP_1_REGS                     (0x02540000u)
#define CSL_TSIP_2_REGS                     (0x02580000u)

/** @brief UTOPIA2 Module memory mapped address  */
#define CSL_UTOPIA2_0_REGS                	(0x02B40000u)

/******************************************************************************\
* SRIO Descriptor section
\******************************************************************************/
/** @brief SRIO CPPI RAM memory mapped address  */
#define CSL_SRIO_0_CPII_RAM_REGS           	(0x02E00000u)

/******************************************************************************\
* EMAC Descriptor section
\******************************************************************************/
/** @brief EMAC0 CPPI RAM memory mapped address  */
#define CSL_EMAC0_DSC_BASE_ADDR             (0x02C82000u)
/** @brief EMAC1 CPPI RAM memory mapped address  */
#define CSL_EMAC1_DSC_BASE_ADDR         	(0x02CC2000u)
/** @brief EMAC L2 RAM memory mapped address for descriptors */
#define CSL_EMAC_DSC_BASE_ADDR_L2           (0x00800000u)
/** @brief EMAC DDR RAM memory mapped address for descriptors  */
#define CSL_EMAC_DSC_BASE_ADDR_DDR			(0xE0000000u)
/** EMAC Descriptor Size and Element Count */
#define CSL_EMAC_DSC_SIZE              		(8192)
/** Size of a buffer descriptor, in bytes */
#define CSL_EMAC_DSC_ENTRY_SIZE        		(16)
/** EMAC Descriptor entry count */
#define CSL_EMAC_DSC_ENTRY_COUNT       	(CSL_EMAC_DSC_SIZE/CSL_EMAC_DSC_ENTRY_SIZE)

/******************************************************************************\
* SDRAM Descriptor section
\******************************************************************************/
#define CSL_DDR2_SDRAM_CE0_BASE_ADDR             (0xE0000000u)
#define CSL_DDR2_SDRAM_CE1_BASE_ADDR             (0xF0000000u)

/*****************************************************************************\
* Interrupt Event IDs
\*****************************************************************************/

/**
 * @brief   Interrupt Event IDs
 */
/* Output of event combiner 0, for events 1 to 31  */
#define    CSL_INTC_EVENTID_EVT0                (0)
/* Output of event combiner 0, for events 32 to 63 */
#define    CSL_INTC_EVENTID_EVT1                (1)
/* Output of event combiner 0, for events 64 to 95 */
#define    CSL_INTC_EVENTID_EVT2                (2)
/* Output of event combiner 0, for events 96 to 127 */
#define    CSL_INTC_EVENTID_EVT3                (3)

/* RapidIO Individual interrupt */
#define 	CSL_INTC_EVENTID_RIOINT_LOCAL		(4)
/* Ethernet MAC receive interrupt */
#define 	CSL_INTC_EVENTID_MACRXINT0			(5)
/* Ethernet MAC transmit interrupt	*/
#define   	CSL_INTC_EVENTID_MACTXINT0			(6)
/* Ethernet MAC receive interrupt */
#define 	CSL_INTC_EVENTID_MACRXINT1			(7)
/* Ethernet MAC transmit interrupt */
#define    	CSL_INTC_EVENTID_MACTXINT1			(8)

/** EMU interrupt for:
  * 1. Host scan access
  * 2. DTDMA transfer complete
  * 3. AET interrupt
  */
#define    CSL_INTC_EVENTID_EMU_DTDMA   		(9)
/* Event ID 10 is reserved */

/* EMU real time data exchange receive complete    */
#define    CSL_INTC_EVENTID_EMU_RTDXRX  		(11)
/* EMU RTDX transmit complete   */
#define    CSL_INTC_EVENTID_EMU_RTDXTX  		(12)
/* IDMA Channel 0 Interrupt */
#define    CSL_INTC_EVENTID_IDMA0       		(13)
/* IDMA Channel 1 Interrupt */
#define    CSL_INTC_EVENTID_IDMA1       		(14)
/* TPCC Individual completion interrupt   */
#define    CSL_INTC_EVENTID_EDMA3CCINT_LOCAL   	(15)
/* Local timer intr low   */
#define    CSL_INTC_EVENTID_TINTLO_LOCAL      	(16)
/* Local timer intr high   */
#define    CSL_INTC_EVENTID_TINTHI_LOCAL      	(17)
/* Timer intr low   */
#define    CSL_INTC_EVENTID_TINTLO6      		(18)
/* Timer intr high   */
#define    CSL_INTC_EVENTID_TINTHI6      		(19)
/* Timer intr low   */
#define    CSL_INTC_EVENTID_TINTLO7      		(20)
/* Timer intr high   */
#define    CSL_INTC_EVENTID_TINTHI7      		(21)
/* Timer intr low   */
#define    CSL_INTC_EVENTID_TINTLO8      		(22)
/* Timer intr high   */
#define    CSL_INTC_EVENTID_TINTHI8      		(23)
/* Timer intr low   */
#define    CSL_INTC_EVENTID_TINTLO9      		(24)
/* Timer intr high   */
#define    CSL_INTC_EVENTID_TINTHI9     		(25)
/* Timer intr low   */
#define    CSL_INTC_EVENTID_TINTLO10     		(26)
/* Timer intr high   */
#define    CSL_INTC_EVENTID_TINTHI10     		(27)
/* Timer intr low   */
#define    CSL_INTC_EVENTID_TINTLO11     		(28)
/* Timer intr high   */
#define    CSL_INTC_EVENTID_TINTHI11     		(29)
/* Utopia PDMA receive intr   */
#define    CSL_INTC_EVENTID_PRINT     			(30)
/* Utopia PDMA transmit intr   */
#define    CSL_INTC_EVENTID_PXINT     			(31)
/* TSIP receive frame sync intr   */
#define    CSL_INTC_EVENTID_RFSINT0     		(32)
/* TSIP receive super frame intr   */
#define    CSL_INTC_EVENTID_RSFINT0     		(33)
/* TSIP transmit frame sync intr   */
#define    CSL_INTC_EVENTID_XFSINT0     		(34)
/* TSIP transmit super frame intr   */
#define    CSL_INTC_EVENTID_XSFINT0     		(35)
/* TSIP receive frame sync intr   */
#define    CSL_INTC_EVENTID_RFSINT1     		(36)
/* TSIP receive super frame intr   */
#define    CSL_INTC_EVENTID_RSFINT1     		(37)
/* TSIP transmit frame sync intr   */
#define    CSL_INTC_EVENTID_XFSINT1     		(38)
/* TSIP transmit super frame intr   */
#define    CSL_INTC_EVENTID_XSFINT1     		(39)
/* TSIP receive frame sync intr   */
#define    CSL_INTC_EVENTID_RFSINT2     		(40)
/* TSIP receive super frame intr   */
#define    CSL_INTC_EVENTID_RSFINT2     		(41)
/* TSIP transmit frame sync intr   */
#define    CSL_INTC_EVENTID_XFSINT2     		(42)
/* TSIP transmit super frame intr   */
#define    CSL_INTC_EVENTID_XSFINT2     		(43)
/* RapidIO common/error intr    */
#define    CSL_INTC_EVENTID_RIOINT6     		(44)
/* RapidIO common/error intr    */
#define    CSL_INTC_EVENTID_RIOINT7     		(45)

/* Event ID 46-49 are reserved */

/* TSIP receive/transmit error Interrupt */
#define    CSL_INTC_EVENTID_ERRINT0   			(50)

/* Event ID 51 is reserved */

/* TSIP receive/transmit error Interrupt */
#define    CSL_INTC_EVENTID_ERRINT1     		(52)

/* Event ID 53 is reserved */

/* TSIP receive/transmit error Interrupt */
#define    CSL_INTC_EVENTID_ERRINT2     		(54)

/* Event ID 55 is reserved */

/* Utopia Interrupt           */
#define    CSL_INTC_EVENTID_UINT     			(56)
/* TPCC Error Interrupt           */
#define    CSL_INTC_EVENTID_EDMA3CC_ERRINT    	(57)
/* TPCC memory protection Interrupt     */
#define    CSL_INTC_EVENTID_EDMA3CC_MPINT     	(58)
/* TPCC Error Interrupt           */
#define    CSL_INTC_EVENTID_EDMA3CC_ERRINT0   	(59)
/* TPCC Error Interrupt           */
#define    CSL_INTC_EVENTID_EDMA3CC_ERRINT1   	(60)
/* TPCC Error Interrupt           */
#define    CSL_INTC_EVENTID_EDMA3CC_ERRINT2   	(61)
/* TPCC Error Interrupt           */
#define    CSL_INTC_EVENTID_EDMA3CC_ERRINT3   	(62)
/* SMC memory protection Interrupt */
#define    CSL_INTC_EVENTID_SMCMPINT 		  	(63)
/* SMC profiler consolidated Event */
#define    CSL_INTC_EVENTID_SMCPEVT 		  	(64)
/* Power & Sleep controller interrupt */
#define    CSL_INTC_EVENTID_PSC_ALLINT 		  	(65)
/* CC AET Event */
#define    CSL_INTC_EVENTID_EDMA3CC_AETEVT 	  	(66)
/* CC Completion Interrupt - Mask6 */
#define    CSL_INTC_EVENTID_EDMA3CC_INT6 	  	(67)
/* CC Completion Interrupt - Mask7 */
#define    CSL_INTC_EVENTID_EDMA3CC_INT7 	  	(68)
/* CC GINT */
#define    CSL_INTC_EVENTID_EDMA3CC_GINT 	  	(69)
/* Ethernet MAC common interrupt */
#define    CSL_INTC_EVENTID_MACINT0			  	(70)
/* Ethernet MAC common interrupt */
#define    CSL_INTC_EVENTID_MACINT1			  	(71)
/* I2C interrupt       */
#define    CSL_INTC_EVENTID_I2CINT         	  	(72)
/* Local GPIO interrupt */
#define    CSL_INTC_EVENTID_GPINT_LOCAL 	  	(73)
/* GPIO interrupt	*/
#define    CSL_INTC_EVENTID_GPINT6	  		  	(74)
/* GPIO interrupt	*/
#define    CSL_INTC_EVENTID_GPINT7	  		  	(75)
/* GPIO interrupt	*/
#define    CSL_INTC_EVENTID_GPINT8			  	(76)
/* GPIO interrupt	*/
#define    CSL_INTC_EVENTID_GPINT9			  	(77)
/* GPIO interrupt	*/
#define    CSL_INTC_EVENTID_GPINT10			  	(78)
/* GPIO interrupt	*/
#define    CSL_INTC_EVENTID_GPINT11			  	(79)
/* GPIO interrupt	*/
#define    CSL_INTC_EVENTID_GPINT12			  	(80)
/* GPIO interrupt	*/
#define    CSL_INTC_EVENTID_GPINT13			  	(81)
/* GPIO interrupt	*/
#define    CSL_INTC_EVENTID_GPINT14			  	(82)
/* GPIO interrupt	*/
#define    CSL_INTC_EVENTID_GPINT15			  	(83)
/* Inter DSP interrupt */
#define    CSL_INTC_EVENTID_IPC_LOCAL		  	(84)
/* Host common interrupt */
#define    CSL_INTC_EVENTID_HPI_INT			  	(85)

/* Event ID 86 is reserved */

/* interrupt from CPU */
#define    CSL_INTC_EVENTID_CPUINT0			  	(87)
/* interrupt from CPU */
#define    CSL_INTC_EVENTID_CPUINT1			  	(88)
/* interrupt from CPU */
#define    CSL_INTC_EVENTID_CPUINT2			  	(89)
/* interrupt from CPU */
#define    CSL_INTC_EVENTID_CPUINT3			  	(90)
/* interrupt from CPU */
#define    CSL_INTC_EVENTID_CPUINT4			  	(91)
/* interrupt from CPU */
#define    CSL_INTC_EVENTID_CPUINT5			  	(92)
/* L2 wake interrupt */
#define    CSL_INTC_EVENTID_L2PDWAKE		  	(93)

/* Event ID 94 and 95 are reserved */

/* Dropped CPU interrupt event */
#define    CSL_INTC_EVENTID_INTERR          	(96)
/* EMC Invalid IDMA parameters     */
#define    CSL_INTC_EVENTID_EMC_IDMAERR     	(97)
/* PBIST interrupt */
#define    CSL_INTC_EVENTID_PBISTINT	    	(98)

/* Event ID 99 is reserved */

/* EFI Interrupt from side A    */
#define    CSL_INTC_EVENTID_EFIINTA         	(100)
/* EFI Interrupt from side B    */
#define    CSL_INTC_EVENTID_EFIINTB         	(101)

/* Event ID 102-112 are reserved */

/* L1P Single bit error detected during DMA read */
#define    CSL_INTC_EVENTID_L1P_ED1         	(113)

/* Event ID 114-115 are reserved */

/* L2 single bit error detected */
#define    CSL_INTC_EVENTID_L2_ED1         		(116)
/* L2 two bit error detected */
#define    CSL_INTC_EVENTID_L2_ED2         		(117)
/* Power Down sleep interrupt */
#define    CSL_INTC_EVENTID_PDC_INT        		(118)

/* Event ID 119 is reserved */

/* L1P CPU memory protection fault */
#define    CSL_INTC_EVENTID_L1P_CMPA       		(120)
/* L1P DMA memory protection fault */
#define    CSL_INTC_EVENTID_L1P_DMPA       		(121)
/* L1D CPU memory protection fault */
#define    CSL_INTC_EVENTID_L1D_CMPA       		(122)
/* L1D DMA memory protection fault */
#define    CSL_INTC_EVENTID_L1D_DMPA       		(123)
/* L2 CPU memory protection fault */
#define    CSL_INTC_EVENTID_L2_CMPA        		(124)
/* L2 DMA memory protection fault */
#define    CSL_INTC_EVENTID_L2_DMPA        		(125)
/* CPU memory protection fault */
#define    CSL_INTC_EVENTID_IDMA_CMPA       	(126)
/* L2 DMA memory protection fault */
#define    CSL_INTC_EVENTID_IDMA_BUSERR     	(127)


/**** EDMA RELATED DEFINES  *********/

/**************************************************************************\
*  EDMA3 Parameterizable Configuration:- These are fed directly from the RTL
*  parameters for the given SOC
\**************************************************************************/

#define CSL_EDMA3_NUM_DMACH            64
#define CSL_EDMA3_NUM_QDMACH            4
#define CSL_EDMA3_NUM_PARAMSETS       256
#define CSL_EDMA3_NUM_EVQUE             4
#define CSL_EDMA3_CHMAPEXIST            1
#define CSL_EDMA3_NUM_REGIONS           8
#define CSL_EDMA3_MEMPROTECT            1

/**************************************************************************\
* EDMA3 Channel Instance count
\**************************************************************************/
#define CSL_EDMA3_CHA_CNT              68

/* EDMA channel synchronization events */

/* GPIO event 0  */
#define CSL_EDMA3_CHA_GPINT0   		0
/* GPIO event 1  */
#define CSL_EDMA3_CHA_GPINT1   		1
/* GPIO event 2  */
#define CSL_EDMA3_CHA_GPINT2   		2
/* GPIO event 3  */
#define CSL_EDMA3_CHA_GPINT3	   	3
/* GPIO event 4  */
#define CSL_EDMA3_CHA_GPINT4	   	4
/* GPIO event 5  */
#define CSL_EDMA3_CHA_GPINT5   		5
/* GPIO event 6  */
#define CSL_EDMA3_CHA_GPINT6	   	6
/* GPIO event 7  */
#define CSL_EDMA3_CHA_GPINT7	   	7
/* Timer 6 lower counter event */
#define CSL_EDMA3_CHA_TEVTLO6	   	8
/* Timer 6 higher counter event */
#define CSL_EDMA3_CHA_TEVTHI6	   	9
/* Timer 7 lower counter event */
#define CSL_EDMA3_CHA_TEVTLO7   	10
/* Timer 7 higher counter event */
#define CSL_EDMA3_CHA_TEVTHI7	   	11
/* Timer 8 lower counter event */
#define CSL_EDMA3_CHA_TEVTLO8    	12
/* Timer 8 higher counter event */
#define CSL_EDMA3_CHA_TEVTHI8   	13
/* Timer 9 lower counter event */
#define CSL_EDMA3_CHA_TEVTLO9   	14
/* Timer 9 higher counter event */
#define CSL_EDMA3_CHA_TEVTHI9   	15
/* Timer 10 lower counter event */
#define CSL_EDMA3_CHA_TEVTLO10  	16
/* Timer 10 higher counter event */
#define CSL_EDMA3_CHA_TEVTHI10  	17
/* Timer 11 lower counter event */
#define CSL_EDMA3_CHA_TEVTLO11  	18
/* Timer 11 higher counter event */
#define CSL_EDMA3_CHA_TEVTHI11   	19
/* I2C receive event */
#define CSL_EDMA3_CHA_ICREVT   		20
/* I2C transmit event */
#define CSL_EDMA3_CHA_ICXEVT   		21
/* Utopia event */
#define CSL_EDMA3_CHA_PXEVT0  		22
/* Utopia event */
#define CSL_EDMA3_CHA_PXEVT1  		23
/* Utopia event */
#define CSL_EDMA3_CHA_PXEVT2  		24
/* Utopia event */
#define CSL_EDMA3_CHA_PXEVT3  		25
/* Utopia event */
#define CSL_EDMA3_CHA_PXEVT4	   	26
/* Utopia event */
#define CSL_EDMA3_CHA_PXEVT5	   	27
/* RapidID event  */
#define CSL_EDMA3_CHA_RIOINT4	  	28
/* RapidID event  */
#define CSL_EDMA3_CHA_RIOINT5	  	29
/* RapidID event  */
#define CSL_EDMA3_CHA_RIOINT6	  	30
/* RapidID event  */
#define CSL_EDMA3_CHA_RIOINT7	  	31

/* Event ID 32-63 are reserved */


/* QDMA channels */
#define    CSL_EDMA3_QCHA_0         64   /* QDMA Channel 0*/
#define    CSL_EDMA3_QCHA_1         65   /* QDMA Channel 1*/
#define    CSL_EDMA3_QCHA_2         66   /* QDMA Channel 2*/
#define    CSL_EDMA3_QCHA_3         67   /* QDMA Channel 3*/


/* Enumerations for EDMA Event Queues */
typedef enum {
	CSL_EDMA3_QUE_0 = 0, /* Queue 0 */
	CSL_EDMA3_QUE_1 = 1, /* Queue 1 */
	CSL_EDMA3_QUE_2 = 2, /* Queue 2 */
	CSL_EDMA3_QUE_3 = 3  /* Queue 3 */
} CSL_Edma3Que;

/* Enumerations for EDMA Transfer Controllers
 *
 * There are 4 Transfer Controllers. Typically a one to one mapping exists
 * between Event Queues and Transfer Controllers.
 *
 */
typedef enum {
	CSL_EDMA3_TC_0 = 0, /* TC 0 */
	CSL_EDMA3_TC_1 = 1, /* TC 1 */
	CSL_EDMA3_TC_2 = 2, /* TC 2 */
	CSL_EDMA3_TC_3 = 3  /* TC 3 */
} CSL_Edma3Tc;

#define CSL_EDMA3_REGION_GLOBAL    -1
#define CSL_EDMA3_REGION_0          0
#define CSL_EDMA3_REGION_1          1
#define CSL_EDMA3_REGION_2          2
#define CSL_EDMA3_REGION_3          3
#define CSL_EDMA3_REGION_4          4
#define CSL_EDMA3_REGION_5          5
#define CSL_EDMA3_REGION_6          6
#define CSL_EDMA3_REGION_7          7

/*********** DAT RELATED DEFINES ******************/

/**************************************************************************\
*  Parameterizable Configuration:- These are fed directly from the RTL
*  parameters for the given SOC
\**************************************************************************/
/**************************************************************************\
* Channel Instance count
\**************************************************************************/
/** @brief Number of Generic Channel instances */


/** @brief Enumerations for EDMA channels
*
*  There are 4 QDMA channels -
*
*/

#define CSL_DAT_QCHA_0		   	0 /**< QDMA Channel 0*/
#define CSL_DAT_QCHA_1		   	1 /**< QDMA Channel 1*/
#define CSL_DAT_QCHA_2    	   	2 /**< QDMA Channel 2*/
#define CSL_DAT_QCHA_3		   	3 /**< QDMA Channel 3*/

/** @brief Enumerations for EDMA Event Queues
*
*  There are 4 Event Queues. Q0 is the highest priority and Q3 is the least priority
*
*/
typedef enum {
	CSL_DAT_PRI_DEFAULT = 0, /* Queue 0 is default */
	CSL_DAT_PRI_0 		= 0, /* Queue 0 */
	CSL_DAT_PRI_1 		= 1, /* Queue 1 */
	CSL_DAT_PRI_2 		= 2, /* Queue 2 */
	CSL_DAT_PRI_3 		= 3  /* Queue 3 */
} CSL_DatPriority;

/** @brief Enumeration for EDMA Regions
*
*
*/

#define	CSL_DAT_REGION_GLOBAL  -1  /* Global Region */
#define	CSL_DAT_REGION_0        0         /* EDMA Region 0 */
#define	CSL_DAT_REGION_1        1         /* EDMA Region 1 */
#define	CSL_DAT_REGION_2        2         /* EDMA Region 2 */
#define	CSL_DAT_REGION_3        3         /* EDMA Region 3 */
#define	CSL_DAT_REGION_4        4         /* EDMA Region 4 */
#define	CSL_DAT_REGION_5        5         /* EDMA Region 5 */
#define	CSL_DAT_REGION_6        6         /* EDMA Region 6 */
#define	CSL_DAT_REGION_7        7         /* EDMA Region 7 */

#endif  /* _SOC_H_*/
